//**********************************************************************
// This source code is provided as an example.  No warranty is expressed
// or implied.  It is your responsibility to determine its suitability
// to your application, to modify it as necessary, and to validate
// its correctness.
//
// Licensed Materials - Property of IBM
// (c) Copyright IBM Corporation 2000. All Rights Reserved.
//
// US Government Users Restricted Rights - Use, duplication, or
// disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
//**********************************************************************
// Revision / History
// Defect     Date       Who      Description
// ---------- 01/03/2000 ldbader  Module created
//**********************************************************************

package com.ibm.etill.ldbcardcassette;

import  com.ibm.etill.framework.payapi.PaymentAPIConstants;

/***********************************************************************
* This interface contains all the constants used by the cassette,
* including
* <ul>
* <li> The cassette name
* <li> The payment type
* <li> The resource bundle ID
* <li> The trace ID
* <li> The database table names for this cassette
* <li> The database column names for this cassette
* <li> Cassette dependent XML keys
* <li> Database view names for this cassette
* <li> Database column names for the views used by this cassette
* <li> Column names organized by database table
* <li> Cassette dependent protocol data keywords
* <li> Cassette secondary return codes that identify parameters
* <li> Cassette dependent secondary return codes
* <li> Cassette dependent message numbers
* </ul>
***********************************************************************/
public interface LdbCardConstants
   extends PaymentAPIConstants
{

   //<gutter>
   //</gutter>

   // In this version of the Payment Manager, the cassette's name is
   // used in multiple ways.
   // 1) It is used by the framework to dynamically construct the
   //    the fully qualified cassette class name which, in turn,
   //    is used to dynmically load the cassette's implementation of
   //    the Cassette class and contruct the cassette object.
   // 2) It is used by the framework to dynamically construct the
   //    the fully qualified cassette query class name which, in turn,
   //    is used to dynmically load the cassette's implementation of
   //    the CassetteQuery class and contruct the query object.
   // 3) It is used by the framework to dynamically construct the
   //    name of the cassette's properties file which, in turn, is
   //    loaded as a resource bundle.
   // 4) When a request contains a PaymentType parameter, the framework
   //    compares its value to the various cassette names and routes
   //    the request to the matching cassette.
   // 5) It is used by the cassette to specify the resource bundle
   //    identifier when issueing log messages or retreiving data
   //    from the cassette's resource bundle.
   // 6) It is used by the cassette to identify trace messages.
   public static final String CASSETTE_NAME     = "LdbCard";
   public static final String PAYMENT_TYPE      = CASSETTE_NAME;
   public static final String RB_ID             = CASSETTE_NAME;
   public static final String TRACE_ID          = CASSETTE_NAME;

   // These constants are used to define the cassette's table names.
   public static final String TBL_ACCOUNT       = "LDBCARDACCOUNT";
   public static final String TBL_BATCH         = "LDBCARDBATCH";
   public static final String TBL_CREDIT        = "LDBCARDCREDIT";
   public static final String TBL_ORDER         = "LDBCARDORDER";
   public static final String TBL_PAYMENT       = "LDBCARDPAYMENT";

   // These constants are used to define column names in the cassette
   // tables that must match column names in the framework tables.
   // They are used exclusively for index columns.
   public static final String COL_ACCOUNT       = "AccountNumber";
   public static final String COL_BATCH         = "BatchNumber";
   public static final String COL_CREDIT        = "CreditNumber";
   public static final String COL_MERCHANT_NAME = "MerchantName";
   public static final String COL_ORDER         = "OrderNumber";
   public static final String COL_PAYMENT       = "PaymentNumber";

   // These constants are used to define column names for cassette
   // dependent data in the cassette's database tables.
   public static final String COL_ADDRESS       = "Address";
   public static final String COL_AMOUNT        = "AmountApproved";
   public static final String COL_APPROVAL      = "ApprovalCode";
   public static final String COL_BRAND         = "Brand";
   public static final String COL_CLOSE_TIME    = "BatchCloseTime";
   public static final String COL_CLOSED_TO_TRANS = "ClosedToNewTrans";
   public static final String COL_CURRENCY      = "Currency";
   public static final String COL_EXPIRY        = "Expiry";
   public static final String COL_LDBCARD_ID    = "LdbCardId";
   public static final String COL_MAX_BATCH_SIZE= "MaxBatchSize";
   public static final String COL_MERCHANT      = "MerchantNumber";
   public static final String COL_MIN_BATCH_TOTAL= "MinBatchTotal";
   public static final String COL_PAN           = "Pan";
   public static final String COL_PASSWORD      = "Password";
   public static final String COL_POSTAL_CODE   = "PostalCode";
   public static final String COL_REASON        = "DeclineReason";
   public static final String COL_URL           = "LdbCardRmiUrl";
   public static final String COL_USER          = "UserId";

   // These constants are used to define XML labels for cassette
   // dependent data in the cassette's database tables.  These
   // values must match the values assumed by the cassette's
   // Payment Server Presentation Language (PSPL) descriptions.
   public static final String XDM_ACCOUNT       = "AccountNumber";
   public static final String XDM_ADDRESS       = "Address";
   public static final String XDM_AMOUNT        = "AmountApproved";
   public static final String XDM_APPROVAL      = "ApprovalCode";
   public static final String XDM_BRAND         = "Brand";
   public static final String XDM_CURRENCY      = "Currency";
   public static final String XDM_EXPIRY        = "Expiry";
   public static final String XDM_LDBCARD_ID    = "LdbCardId";
   public static final String XDM_PAN           = "Pan";
   public static final String XDM_PASSWORD      = "Password";
   public static final String XDM_POSTAL_CODE   = "PostalCode";
   public static final String XDM_REASON        = "DeclineReason";
   public static final String XDM_URL           = "LdbCardRmiUrl";
   public static final String XDM_USER          = "UserId";
   public static final String XDM_CLOSE_TIME    = "BatchCloseTime";
   public static final String XDM_MIN_BATCH_TOTAL= "MinBatchTotal";
   public static final String XDM_MAX_BATCH_SIZE= "MaxBatchSize";
   public static final String XDM_CLOSED_TO_TRANS = "ClosedToTrans";

   // View Tables

   public static final String VIEW_ORDERS =
      "LdbCardOrderView";
   public static final String VIEW_PAYMENTS =
      "LdbCardPaymentView";
   public static final String VIEW_BATCH_PAYMENTS =
      "LdbCardPayBatView";
   public static final String VIEW_CREDITS =
      "LdbCardCreditView";
   public static final String VIEW_BATCH_CREDITS =
      "LdbCardCreBatView";
   public static final String VIEW_BATCHES =
      "LdbCardBatchView";
   public static final String VIEW_ACCOUNTS =
      "LdbCardAccountView";

   public static final String VIEW_ACCOUNT      = COL_ACCOUNT;
   public static final String VIEW_ADDRESS      = COL_ADDRESS;
   public static final String VIEW_AMOUNT       = COL_AMOUNT;
   public static final String VIEW_APPROVAL     = COL_APPROVAL;
   public static final String VIEW_BATCH        = COL_BATCH;
   public static final String VIEW_BRAND        = COL_BRAND;
   public static final String VIEW_CLOSE_TIME   = COL_CLOSE_TIME;
   public static final String VIEW_CLOSED_TO_TRANS = COL_CLOSED_TO_TRANS;
   public static final String VIEW_CREDIT       = COL_CREDIT;
   public static final String VIEW_CURRENCY     = COL_CURRENCY;
   public static final String VIEW_EXPIRY       = COL_EXPIRY;
   public static final String VIEW_LDBCARD_ID   = COL_LDBCARD_ID;
   public static final String VIEW_MAX_BATCH_SIZE = COL_MAX_BATCH_SIZE;
   public static final String VIEW_MERCHANT     = COL_MERCHANT;
   public static final String VIEW_MERCHANT_NAME= COL_MERCHANT_NAME;
   public static final String VIEW_MIN_BATCH_TOTAL = COL_MIN_BATCH_TOTAL;
   public static final String VIEW_ORDER        = COL_ORDER;
   public static final String VIEW_PAN          = COL_PAN;
   public static final String VIEW_PASSWORD     = COL_PASSWORD;
   public static final String VIEW_PAYMENT      = COL_PAYMENT;
   public static final String VIEW_POSTAL_CODE  = COL_POSTAL_CODE;
   public static final String VIEW_REASON       = COL_REASON;
   public static final String VIEW_USER         = COL_USER;
   public static final String VIEW_URL          = COL_URL;

   // Account table column names, from left to right:
   public static final String ACC_MERCHANT      = COL_MERCHANT;
   public static final String ACC_ACCOUNT       = COL_ACCOUNT;
   public static final String ACC_CURRENCY      = COL_CURRENCY;
   public static final String ACC_USER          = COL_USER;
   public static final String ACC_PASSWORD      = COL_PASSWORD;
   public static final String ACC_LDBCARD_ID    = COL_LDBCARD_ID;
   public static final String ACC_URL           = COL_URL;
   public static final String ACC_CLOSE_TIME    = COL_CLOSE_TIME;
   public static final String ACC_MIN_BATCH_TOTAL= COL_MIN_BATCH_TOTAL;
   public static final String ACC_MAX_BATCH_SIZE= COL_MAX_BATCH_SIZE;

   // Batch table column names, from left to right:
   public static final String BAT_MERCHANT      = COL_MERCHANT;
   public static final String BAT_BATCH         = COL_BATCH;
   public static final String BAT_APPROVAL      = COL_APPROVAL;
   public static final String BAT_REASON        = COL_REASON;
   public static final String BAT_CLOSED_TO_TRANS = COL_CLOSED_TO_TRANS;

   // Credit table column names, from left to right:
   public static final String CRE_MERCHANT      = COL_MERCHANT;
   public static final String CRE_ORDER         = COL_ORDER;
   public static final String CRE_CREDIT        = COL_CREDIT;
   public static final String CRE_APPROVAL      = COL_APPROVAL;
   public static final String CRE_REASON        = COL_REASON;

   // Order table column names, from left to right:
   public static final String ORD_MERCHANT      = COL_MERCHANT;
   public static final String ORD_ORDER         = COL_ORDER;
   public static final String ORD_ACCOUNT       = COL_ACCOUNT;
   public static final String ORD_AMOUNT        = COL_AMOUNT;
   public static final String ORD_PAN           = COL_PAN;
   public static final String ORD_EXPIRY        = COL_EXPIRY;
   public static final String ORD_BRAND         = COL_BRAND;
   public static final String ORD_ADDRESS       = COL_ADDRESS;
   public static final String ORD_POSTAL_CODE   = COL_POSTAL_CODE;

   // Payment table column names, from left to right:
   public static final String PAY_MERCHANT      = COL_MERCHANT;
   public static final String PAY_ORDER         = COL_ORDER;
   public static final String PAY_PAYMENT       = COL_PAYMENT;
   public static final String PAY_APPROVAL      = COL_APPROVAL;
   public static final String PAY_REASON        = COL_REASON;

   // Cassette Dependent Protocol Data Keyworkds
   public static final String PD_PAY_PAN            = PD_PAN;
   public static final String PD_PAY_EXPIRY         = PD_EXPIRY;
   public static final String PD_PAY_BRAND          = PD_BRAND;
   public static final String PD_PAY_CARDHOLDERNAME = PD_CARDHOLDERNAME;
   public static final String PD_PAY_STREETADDRESS  = PD_AVS_STREETADDRESS;
   public static final String PD_PAY_STREETADDR     = PD_AVS_STREETADDR;
   public static final String PD_PAY_CITY           = PD_AVS_CITY;
   public static final String PD_PAY_STATEPROVINCE  = PD_AVS_STATEPROVINCE;
   public static final String PD_PAY_STATEPROV      = PD_AVS_STATEPROV;
   public static final String PD_PAY_COUNTRYCODE    = PD_AVS_COUNTRYCODE;
   public static final String PD_PAY_POSTALCODE     = PD_AVS_POSTALCODE;
   public static final String PD_PAY_B_STREETADDRESS= PD_BILL_STREETADDRESS;
   public static final String PD_PAY_B_STREETADDR   = PD_BILL_STREETADDR;
   public static final String PD_PAY_B_CITY         = PD_BILL_CITY;
   public static final String PD_PAY_B_STATEPROVINCE= PD_BILL_STATEPROVINCE;
   public static final String PD_PAY_B_STATEPROV    = PD_BILL_STATEPROV;
   public static final String PD_PAY_B_COUNTRYCODE  = PD_BILL_COUNTRYCODE;
   public static final String PD_PAY_B_COUNTRYCOD   = PD_BILL_COUNTRYCOD;
   public static final String PD_PAY_B_POSTALCODE   = PD_BILL_POSTALCODE;
   public static final String PD_ACC_CURRENCY       = PD_CURRENCY;
   public static final String PD_ACC_USER           = "$USERID";
   public static final String PD_ACC_PASSWORD       = "$PASSWORD";
   public static final String PD_ACC_LDBCARDID      = "$LDBCARDID";
   public static final String PD_ACC_URL            = "$LDBCARDRMIURL";
   public static final String PD_ACC_MAX_BATCH_SIZE = "$MAXBATCHSIZE";
   public static final String PD_ACC_MIN_BATCH_TOTAL = "$MINBATCHTOTAL";
   public static final String PD_ACC_BATCH_CLOSE_TIME="$BATCHCLOSETIME";

   // Cassette Return Codes That Identify A Particular Parameter
   public static final short  SRC_CASSETTE_CARDHOLDERNAME        = 10001;
   public static final short  SRC_CASSETTE_CURRENCY              = 10002;
   public static final short  SRC_CASSETTE_USER                  = 10003;
   public static final short  SRC_CASSETTE_PASSWORD              = 10004;
   public static final short  SRC_CASSETTE_LDBCARDID             = 10005;
   public static final short  SRC_CASSETTE_LDBCARDRMIURL         = 10006;
   public static final short  SRC_CASSETTE_BATCH_CLOSE_TIME      = 10007;
   public static final short  SRC_CASSETTE_MIN_BATCH_TOTAL       = 10008;
   public static final short  SRC_CASSETTE_MAX_BATCH_SIZE        = 10009;

   // Cassette Dependent Secondary Return Codes
   public static final short  SRC_METHOD_NOT_IMPLEMENTED         = 20000;
   public static final short  SRC_CASSETTE_BUNDLE_ID_MISMATCH    = 20001;

   public static final short  SRC_ACCOUNT_SELECT_SQL_FAILURE     = 21000;
   public static final short  SRC_ACCOUNT_SELECT_CLOSE_FAILURE   = 21001;
   public static final short  SRC_ACCOUNT_CREATE_ROW_FAILURE     = 21002;
   public static final short  SRC_ACCOUNT_CREATE_SQL_FAILURE     = 21003;
   public static final short  SRC_ACCOUNT_UPDATE_ROW_FAILURE     = 21004;
   public static final short  SRC_ACCOUNT_UPDATE_SQL_FAILURE     = 21005;
   public static final short  SRC_ACCOUNT_DELETE_ROW_FAILURE     = 21006;
   public static final short  SRC_ACCOUNT_DELETE_SQL_FAILURE     = 21007;
   public static final short  SRC_ACCOUNT_MORE_THAN_ONE_BATCH    = 21008;
   public static final short  SRC_ACCOUNT_NULL_BATCH_NUMBER      = 21009;
   public static final short  SRC_ACCOUNT_ICV_FAILURE            = 21010;
   public static final short  SRC_ACCOUNT_NULL_BATCH_CLOSE_TIME  = 21011;
   public static final short  SRC_ACCOUNT_NULL_MIN_BATCH_TOTAL   = 21012;
   public static final short  SRC_ACCOUNT_NULL_MAX_BATCH_SIZE    = 21013;

   public static final short  SRC_BATCH_SELECT_ROW_FAILURE       = 22000;
   public static final short  SRC_BATCH_SELECT_BATCH_MISSING     = 22001;
   public static final short  SRC_BATCH_SELECT_SQL_FAILURE       = 22002;
   public static final short  SRC_BATCH_SELECT_CLOSE_FAILURE     = 22003;
   public static final short  SRC_BATCH_CREATE_ROW_FAILURE       = 22004;
   public static final short  SRC_BATCH_CREATE_SQL_FAILURE       = 22005;
   public static final short  SRC_BATCH_UPDATE_ROW_FAILURE       = 22006;
   public static final short  SRC_BATCH_UPDATE_SQL_FAILURE       = 22007;
   public static final short  SRC_BATCH_DELETE_ROW_FAILURE       = 22008;
   public static final short  SRC_BATCH_DELETE_SQL_FAILURE       = 22009;
   public static final short  SRC_BATCH_NULL_ORDER_FOR_PAYMENT   = 22010;
   public static final short  SRC_BATCH_NULL_PAYMENT             = 22011;
   public static final short  SRC_BATCH_BAD_BATCH_IN_PAYMENT     = 22012;
   public static final short  SRC_BATCH_NULL_ORDER_FOR_CREDIT    = 22013;
   public static final short  SRC_BATCH_NULL_CREDIT              = 22014;
   public static final short  SRC_BATCH_BAD_BATCH_IN_CREDIT      = 22015;
   public static final short  SRC_BATCH_PURGE_INCOMPLETE         = 22016;
   public static final short  SRC_BATCH_CLOSE_WORK_ITEM_FAILURE  = 22017;
   public static final short  SRC_BATCH_TIMER_WORK_ITEM_FAILURE  = 22018;
   public static final short  SRC_BATCH_BAD_ADD_PAYMENT_STATE    = 22019;
   public static final short  SRC_BATCH_BAD_ADD_CREDIT_STATE     = 22020;

   public static final short  SRC_ORDER_SELECT_ROW_FAILURE       = 23000;
   public static final short  SRC_ORDER_SELECT_ORDER_MISSING     = 23001;
   public static final short  SRC_ORDER_SELECT_SQL_FAILURE       = 23002;
   public static final short  SRC_ORDER_SELECT_CLOSE_FAILURE     = 23003;
   public static final short  SRC_ORDER_CREATE_ROW_FAILURE       = 23004;
   public static final short  SRC_ORDER_CREATE_SQL_FAILURE       = 23005;
   public static final short  SRC_ORDER_UPDATE_ROW_FAILURE       = 23006;
   public static final short  SRC_ORDER_UPDATE_SQL_FAILURE       = 23007;
   public static final short  SRC_ORDER_DELETE_ROW_FAILURE       = 23008;
   public static final short  SRC_ORDER_DELETE_SQL_FAILURE       = 23009;

   public static final short  SRC_PAYMENT_SELECT_ROW_FAILURE     = 24000;
   public static final short  SRC_PAYMENT_SELECT_PAYMENT_MISSING = 24001;
   public static final short  SRC_PAYMENT_SELECT_SQL_FAILURE     = 24002;
   public static final short  SRC_PAYMENT_SELECT_CLOSE_FAILURE   = 24003;
   public static final short  SRC_PAYMENT_CREATE_ROW_FAILURE     = 24004;
   public static final short  SRC_PAYMENT_CREATE_SQL_FAILURE     = 24005;
   public static final short  SRC_PAYMENT_UPDATE_ROW_FAILURE     = 24006;
   public static final short  SRC_PAYMENT_UPDATE_SQL_FAILURE     = 24007;
   public static final short  SRC_PAYMENT_DELETE_ROW_FAILURE     = 24008;
   public static final short  SRC_PAYMENT_DELETE_SQL_FAILURE     = 24009;

   public static final short  SRC_CREDIT_SELECT_ROW_FAILURE      = 25000;
   public static final short  SRC_CREDIT_SELECT_CREDIT_MISSING   = 25001;
   public static final short  SRC_CREDIT_SELECT_SQL_FAILURE      = 25002;
   public static final short  SRC_CREDIT_SELECT_CLOSE_FAILURE    = 25003;
   public static final short  SRC_CREDIT_CREATE_ROW_FAILURE      = 25004;
   public static final short  SRC_CREDIT_CREATE_SQL_FAILURE      = 25005;
   public static final short  SRC_CREDIT_UPDATE_ROW_FAILURE      = 25006;
   public static final short  SRC_CREDIT_UPDATE_SQL_FAILURE      = 25007;
   public static final short  SRC_CREDIT_DELETE_ROW_FAILURE      = 25008;
   public static final short  SRC_CREDIT_DELETE_SQL_FAILURE      = 25009;

   public static final short  SRC_QUERY_ORD_SELECT_SQL_FAILURE   = 26000;
   public static final short  SRC_QUERY_PAY_SELECT_SQL_FAILURE   = 26001;
   public static final short  SRC_QUERY_CRE_SELECT_SQL_FAILURE   = 26002;
   public static final short  SRC_QUERY_BAT_SELECT_SQL_FAILURE   = 26003;
   public static final short  SRC_QUERY_ACC_SELECT_SQL_FAILURE   = 26004;

   // Cassette Dependent Message Numbers
   public static final String MSG_CASSETTE_METHOD_NOT_IMPLEMENTED= "1000";
   public static final String MSG_CASSETTE_BUNDLE_ID_MISMATCH    = "1001";
   public static final String MSG_CASSETTE_HAS_STARTED           = "1002";
   public static final String MSG_CASSETTE_HAS_STOPPED           = "1003";

   public static final String MSG_ACCOUNT_SELECT_SQL_FAILURE     = "2000";
   public static final String MSG_ACCOUNT_SELECT_CLOSE_FAILURE   = "2001";
   public static final String MSG_ACCOUNT_MULTIPLE_ACCOUNTS      = "2002";
   public static final String MSG_ACCOUNT_CREATE_ROW_FAILURE     = "2003";
   public static final String MSG_ACCOUNT_CREATE_SQL_FAILURE     = "2004";
   public static final String MSG_ACCOUNT_UPDATE_ROW_FAILURE     = "2005";
   public static final String MSG_ACCOUNT_UPDATE_SQL_FAILURE     = "2006";
   public static final String MSG_ACCOUNT_DELETE_ROW_FAILURE     = "2007";
   public static final String MSG_ACCOUNT_DELETE_SQL_FAILURE     = "2008";
   public static final String MSG_ACCOUNT_MORE_THAN_ONE_BATCH    = "2009";
   public static final String MSG_ACCOUNT_NULL_BATCH_NUMBER      = "2010";
   public static final String MSG_ACCOUNT_ICV_FAILURE            = "2011";
   public static final String MSG_ACCOUNT_ICV_CMD_FAILURE        = "2012";
   public static final String MSG_ACCOUNT_NULL_BATCH_CLOSE_TIME  = "2013";
   public static final String MSG_ACCOUNT_NULL_MIN_BATCH_TOTAL   = "2014";
   public static final String MSG_ACCOUNT_NULL_MAX_BATCH_SIZE    = "2015";

   public static final String MSG_BATCH_SELECT_ROW_FAILURE       = "3000";
   public static final String MSG_BATCH_SELECT_BATCH_MISSING     = "3001";
   public static final String MSG_BATCH_SELECT_SQL_FAILURE       = "3002";
   public static final String MSG_BATCH_SELECT_CLOSE_FAILURE     = "3003";
   public static final String MSG_BATCH_CREATE_ROW_FAILURE       = "3004";
   public static final String MSG_BATCH_CREATE_SQL_FAILURE       = "3005";
   public static final String MSG_BATCH_UPDATE_ROW_FAILURE       = "3006";
   public static final String MSG_BATCH_UPDATE_SQL_FAILURE       = "3007";
   public static final String MSG_BATCH_DELETE_ROW_FAILURE       = "3008";
   public static final String MSG_BATCH_DELETE_SQL_FAILURE       = "3009";
   public static final String MSG_BATCH_NULL_ORDER_FOR_PAYMENT   = "3010";
   public static final String MSG_BATCH_NULL_PAYMENT             = "3011";
   public static final String MSG_BATCH_BAD_BATCH_IN_PAYMENT     = "3012";
   public static final String MSG_BATCH_NULL_ORDER_FOR_CREDIT    = "3013";
   public static final String MSG_BATCH_NULL_CREDIT              = "3014";
   public static final String MSG_BATCH_BAD_BATCH_IN_CREDIT      = "3015";
   public static final String MSG_BATCH_DEPOSIT_REVERSAL_FAILURE = "3016";
   public static final String MSG_BATCH_PAYMENT_RETRIEVAL_FAILURE= "3017";
   public static final String MSG_BATCH_REFUND_REVERSAL_FAILURE  = "3018";
   public static final String MSG_BATCH_CREDIT_RETRIEVAL_FAILURE = "3019";
   public static final String MSG_BATCH_CLOSE_WORK_ITEM_FAILURE  = "3020";
   public static final String MSG_BATCH_AUTO_CLOSE_FAILURE       = "3021";
   public static final String MSG_BATCH_TIMER_WORK_ITEM_FAILURE  = "3022";
   public static final String MSG_BATCH_BAD_ADD_PAYMENT_STATE    = "3023";
   public static final String MSG_BATCH_BAD_ADD_CREDIT_STATE     = "3024";

   public static final String MSG_ORDER_SELECT_ROW_FAILURE       = "4000";
   public static final String MSG_ORDER_SELECT_ORDER_MISSING     = "4001";
   public static final String MSG_ORDER_SELECT_SQL_FAILURE       = "4002";
   public static final String MSG_ORDER_SELECT_CLOSE_FAILURE     = "4003";
   public static final String MSG_ORDER_CREATE_ROW_FAILURE       = "4004";
   public static final String MSG_ORDER_CREATE_SQL_FAILURE       = "4005";
   public static final String MSG_ORDER_UPDATE_ROW_FAILURE       = "4006";
   public static final String MSG_ORDER_UPDATE_SQL_FAILURE       = "4007";
   public static final String MSG_ORDER_DELETE_ROW_FAILURE       = "4008";
   public static final String MSG_ORDER_DELETE_SQL_FAILURE       = "4009";
   public static final String MSG_ORDER_CLOSE_PAYMENT_STATE_ERROR= "4010";
   public static final String MSG_ORDER_CLOSE_CREDIT_STATE_ERROR = "4011";

   public static final String MSG_PAYMENT_SELECT_ROW_FAILURE     = "5000";
   public static final String MSG_PAYMENT_SELECT_PAYMENT_MISSING = "5001";
   public static final String MSG_PAYMENT_SELECT_SQL_FAILURE     = "5002";
   public static final String MSG_PAYMENT_SELECT_CLOSE_FAILURE   = "5003";
   public static final String MSG_PAYMENT_CREATE_ROW_FAILURE     = "5004";
   public static final String MSG_PAYMENT_CREATE_SQL_FAILURE     = "5005";
   public static final String MSG_PAYMENT_UPDATE_ROW_FAILURE     = "5006";
   public static final String MSG_PAYMENT_UPDATE_SQL_FAILURE     = "5007";
   public static final String MSG_PAYMENT_DELETE_ROW_FAILURE     = "5008";
   public static final String MSG_PAYMENT_DELETE_SQL_FAILURE     = "5009";
   public static final String MSG_PAYMENT_CLOSE_STATE_ERROR      = "5010";

   public static final String MSG_CREDIT_SELECT_ROW_FAILURE      = "6000";
   public static final String MSG_CREDIT_SELECT_CREDIT_MISSING   = "6001";
   public static final String MSG_CREDIT_SELECT_SQL_FAILURE      = "6002";
   public static final String MSG_CREDIT_SELECT_CLOSE_FAILURE    = "6003";
   public static final String MSG_CREDIT_CREATE_ROW_FAILURE      = "6004";
   public static final String MSG_CREDIT_CREATE_SQL_FAILURE      = "6005";
   public static final String MSG_CREDIT_UPDATE_ROW_FAILURE      = "6006";
   public static final String MSG_CREDIT_UPDATE_SQL_FAILURE      = "6007";
   public static final String MSG_CREDIT_DELETE_ROW_FAILURE      = "6008";
   public static final String MSG_CREDIT_DELETE_SQL_FAILURE      = "6009";
   public static final String MSG_CREDIT_CLOSE_STATE_ERROR       = "6010";

   public static final String MSG_QUERY_ORD_SELECT_SQL_FAILURE   = "7000";
   public static final String MSG_QUERY_PAY_SELECT_SQL_FAILURE   = "7001";
   public static final String MSG_QUERY_CRE_SELECT_SQL_FAILURE   = "7002";
   public static final String MSG_QUERY_BAT_SELECT_SQL_FAILURE   = "7003";
   public static final String MSG_QUERY_ACC_SELECT_SQL_FAILURE   = "7004";

}
